@@ -23,11 +23,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 1.3.1
+Version 1.4.0
 
 =cut
 
-our $VERSION = 'v1.3.1';
+our $VERSION = 'v1.4.0';
 
 =head1 SYNOPSIS
 
@@ -79,9 +79,6 @@ HTTP::Response object.
     # to run unit tests
     prove -r t
 
-    # to run functional tests (requires Artifactory running somewhere)
-    perl t_func/functional.t --server <hostname>
-
 =cut
 
 has 'artifactory' => (
@@ -2106,6 +2103,49 @@ sub install_license {
     );
 }
 
+=head2 ha_license_information
+
+Retrieve information about the currently installed licenses in an HA cluster
+
+=cut
+
+sub ha_license_information {
+    my $self = shift;
+
+    my $url = $self->_api_url() . "/system/licenses";
+    return $self->get($url);
+}
+
+=head2 install_ha_cluster_licenses( [ { licenseKey => 'foobar' }, { licenseKey => 'barbaz' } ] )
+
+Install a new license key(s) on an HA cluster
+
+=cut
+
+sub install_ha_cluster_licenses {
+    my ( $self, $ref ) = @_;
+    my $url = $self->_api_url() . "/system/licenses";
+
+    return $self->post(
+        $url,
+        'Content-Type' => 'application/json',
+        content        => $self->_json->encode($ref)
+    );
+}
+
+=head2 delete_ha_cluster_license( 'licenseHash1', 'licenseHash2' )
+
+Deletes a license key from an HA cluster
+
+=cut
+
+sub delete_ha_cluster_license {
+    my ( $self, @licenses ) = @_;
+    my $url = $self->_api_url() . "/system/licenses?";
+    $url .= $self->_handle_non_matrix_props( 'licenseHash', \@licenses );
+    return $self->delete( $url, 'Content-Type' => 'application/json' );
+}
+
 =head2 version_and_addons_information
 
 Retrieve information about the current Artifactory version, revision, and currently installed Add-ons
@@ -2162,6 +2202,26 @@ sub get_reverse_proxy_snippet {
     return $self->get($url);
 }
 
+=head2 create_bootstrap_bundle
+
+This rest is relevant for High Availability set up. It will create a bootstrap bundle on the primary node of an
+Artifactory HA installation that will include all the relevant keys so a new node can access the database and fetch all
+the relevant configuration files. The same bundle must be installed on all nodes during an installation of new nodes or
+if upgrading from a version older than 5.0. For more details, please refer to Installing Artifactory HA.
+
+=cut
+
+sub create_bootstrap_bundle {
+    my ( $self, $file ) = @_;
+    my $url = $self->_api_url() . "/system/bootstrap_bundle";
+
+    return $self->post(
+        $url,
+        'Content-Type' => 'application/json',
+        content        => $self->_json->encode( { file => $file } )
+    );
+}
+
 =head1 PLUGINS
 
 =cut
